@@ -1,6 +1,6 @@
 package Outthentic;
 
-our $VERSION = '0.0.20';
+our $VERSION = '0.0.21';
 
 1;
 
@@ -367,10 +367,10 @@ Stories are converted into perl test files *.t ( compilation phase ) and saved i
 =head2 An execution phase. 
 
 L<Prove|https://metacpan.org/pod/distribution/Test-Harness/bin/prove> utility recursively executes 
-test files under temporary directory and thus provide final suite execution status.
+test files under temporary directory and thus gives a final suite execution status.
 
-So after all outthentic project is just perl test project with I<.t files inside, the difference is that
-while with common test project >.t files I<are created by user>, in outthentic project *.t files _are generated_
+So after all outthentic project is just perl test project with *.t files inside, the difference is that
+while with common test project *.t files I<are created by user>, in outthentic project *.t files I<are generated>
 by story files.
 
 
@@ -915,7 +915,7 @@ YAML format
 
 =back
 
-.Ini  style configuration files are passed by `--ini' parameter
+.Ini  style configuration files are passed by C<--ini> parameter
 
     $ strun --ini /etc/suites/foo.ini
     
@@ -928,7 +928,7 @@ YAML format
 
 There is no special magic behind ini files, except this should be L<Config Tiny|https://metacpan.org/pod/Config::Tiny> compliant configuration file.
 
-Or you can choose YAML format for suite configuration by using `--yaml' parameter:
+Or you can choose YAML format for suite configuration by using C<--yaml> parameter:
 
     $ strun --yaml /etc/suites/foo.yaml
     
@@ -1032,7 +1032,7 @@ L<Swat|https://github.com/melezhik/swat> - web testing framework consuming Outth
 
 =item *
 
-perl prove, TAP, Test::More
+Perl prove, TAP, Test::More
 
 
 
